Examples Gallery
===============================================================================

Tutorial Examples
-------------------------------------------------------------------------------

.. toctree::

    ex_hello_world
    ex_person
    ex_employee

Widget Examples
-------------------------------------------------------------------------------

.. toctree::

    ex_buttons
    ex_dock_pane
    ex_form
    ex_group_box
    ex_main_window
    ex_menu_bar
    ex_notebook
    ex_progress_bar
    ex_scroll_area
    ex_slider
    ex_spin_box
    ex_splitter
    ex_tool_bar
    ex_window
    ex_window_children


Layout Examples
-------------------------------------------------------------------------------

.. toctree::

    ex_align
    ex_align_offset
    ex_hbox
    ex_hbox_equal_widths
    ex_hbox_spacing
    ex_horizontal
    ex_linear_relations
    ex_vbox
    ex_vertical
    ex_button_ring
    ex_find_replace
    ex_fluid
    ex_manual_hbox
    ex_manual_vbox
    ex_nested_boxes
    ex_nested_containers
